==> mono-1.2.4.tar.bz2: mono-1.2.4/mcs/class/System.Data/System.Data.SqlTypes/SqlAlreadyFilledException.cs <==
//
// System.Data.SqlAlreadyFilledException.cs
//
// Author: Umadevi S (sumadevi@novell.com)
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;
using System.Globalization;
using System.Runtime.Serialization;

namespace System.Data.SqlTypes {

	public sealed class SqlAlreadyFilledException : SqlTypeException, ISerializable
	{
		public SqlAlreadyFilledException()
			: base (Locale.GetText ("A SqlAlreadyFilled exception has occured."))
		{
		}

		public SqlAlreadyFilledException (string message)
			: base (message)
		{
		}

		public SqlAlreadyFilledException (string message, Exception inner)
			: base (message, inner)
		{
		}

		void ISerializable.GetObjectData(SerializationInfo si, StreamingContext context)
		{
			si.AddValue ("SqlAlreadyFilledExceptionMessage", Message, typeof(string));
		}
	}
}

#endif

==> mono-2.6.4.tar.bz2: mono-2.6.4/mcs/class/System.Data/System.Data.SqlTypes/SqlAlreadyFilledException.cs <==
//
// System.Data.SqlAlreadyFilledException.cs
//
// Author: Umadevi S (sumadevi@novell.com)
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;
using System.Globalization;
using System.Runtime.Serialization;

namespace System.Data.SqlTypes {
	[Serializable]
	public sealed class SqlAlreadyFilledException : SqlTypeException
	{
		public SqlAlreadyFilledException()
			: base (Locale.GetText ("A SqlAlreadyFilled exception has occured."))
		{
		}

		public SqlAlreadyFilledException (string message)
			: base (message)
		{
		}

		public SqlAlreadyFilledException (string message, Exception inner)
			: base (message, inner)
		{
		}

		new void GetObjectData(SerializationInfo si, StreamingContext context)
		{
			si.AddValue ("SqlAlreadyFilledExceptionMessage", Message, typeof(string));
		}
	}
}

#endif
